@@ -209,9 +209,14 @@ class TreeEditor(admin.ModelAdmin):
         """
         mptt_opts = item._mptt_meta
         r = ''
-        if hasattr(item, 'get_absolute_url'):
+        try:
+            url = item.get_absolute_url()
+        except (AttributeError,):
+            url = None
+
+        if url:
             r = '<input type="hidden" class="medialibrary_file_path" value="%s" id="_refkey_%d" />' % (
-                        item.get_absolute_url(),
+                        url,
                         item.pk
                       )
 
@@ -392,7 +397,7 @@ class TreeEditor(admin.ModelAdmin):
         pasted_on = tree_manager.get(pk=request.POST.get('pasted_on'))
         position = request.POST.get('position')
 
-        if position in ('last-child', 'left'):
+        if position in ('last-child', 'left', 'right'):
             try:
                 tree_manager.move_node(cut_item, pasted_on, position)
             except InvalidMove, e:
