@@ -9,14 +9,17 @@
 
 from __future__ import absolute_import
 
-from datetime import datetime
+try:
+    import json
+except ImportError:
+    from django.utils import simplejson as json  # Python 2.5
 import zipfile
 import os
 import time
 
 from django.template.defaultfilters import slugify
-from django.utils import simplejson
 from django.conf import settings as django_settings
+from django.utils import timezone
 
 from .models import Category, MediaFile, MediaFileTranslation
 
@@ -43,7 +46,7 @@ def import_zipfile(category_id, overwrite, data):
     is_export_file = False
     info = {}
     try:
-        info = simplejson.loads(z.comment)
+        info = json.loads(z.comment)
         if info['export_magic'] == export_magic:
             is_export_file = True
     except:
@@ -75,7 +78,7 @@ def import_zipfile(category_id, overwrite, data):
 
                 info = {}
                 if is_export_file:
-                    info = simplejson.loads(zi.comment)
+                    info = json.loads(zi.comment)
 
                 mf = None
                 if overwrite:
@@ -124,7 +127,7 @@ def import_zipfile(category_id, overwrite, data):
 
 # ------------------------------------------------------------------------
 def export_zipfile(site, queryset):
-    now  = datetime.today()
+    now  = timezone.now()
     zip_name = "export_%s_%04d%02d%02d.zip" % (slugify(site.domain), now.year, now.month, now.day)
 
     zip_data = open(os.path.join(django_settings.MEDIA_ROOT, zip_name), "w")
@@ -139,11 +142,11 @@ def export_zipfile(site, queryset):
     info = { 'export_magic': export_magic,
              'categories': [ { 'id': cat.id, 'title': cat.title, 'slug': cat.slug, 'parent': cat.parent_id or 0, 'level': len(cat.path_list()) } for cat in used_categories ],
             }
-    zip_file.comment = simplejson.dumps(info)
+    zip_file.comment = json.dumps(info)
 
     for mf in queryset:
         ctime = time.localtime(os.stat(mf.file.path).st_ctime)
-        info = simplejson.dumps({
+        info = json.dumps({
             'copyright': mf.copyright,
             'categories': [ cat.id for cat in mf.categories.all() ],
             'translations': [
